@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: cpl_port.h 7d34df879ac151e8cc377ecd5d0107c579b0c0a2 2019-04-25 12:22:24 +0200 Even Rouault $
+ * $Id: cpl_port.h 7a291205ed24a41c8f9a080fdd9630a6b565427d 2020-06-11 16:05:25 +0200 SpaceIm $
  *
  * Project:  CPL - Common Portability Library
  * Author:   Frank Warmerdam, warmerdam@pobox.com
@@ -8,7 +8,7 @@
  *
  ******************************************************************************
  * Copyright (c) 1998, 2005, Frank Warmerdam <warmerdam@pobox.com>
- * Copyright (c) 2008-2013, Even Rouault <even dot rouault at mines-paris dot org>
+ * Copyright (c) 2008-2013, Even Rouault <even dot rouault at spatialys.com>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -344,7 +344,11 @@ typedef unsigned int  GUIntptr_t;
 
 #ifndef CPL_DLL
 #if defined(_MSC_VER) && !defined(CPL_DISABLE_DLL)
-#  define CPL_DLL     __declspec(dllexport)
+#  ifdef GDAL_COMPILATION
+#    define CPL_DLL __declspec(dllexport)
+#  else
+#    define CPL_DLL
+#  endif
 #  define CPL_INTERNAL
 #else
 #  if defined(USE_GCC_VISIBILITY_FLAG)
@@ -360,6 +364,9 @@ typedef unsigned int  GUIntptr_t;
 #  endif
 #endif
 
+// Marker for unstable API
+#define CPL_UNSTABLE_API CPL_DLL
+
 #endif
 
 /*! @cond Doxygen_Suppress */
@@ -989,6 +996,9 @@ static const char *cvsid_aw() { return( cvsid_aw() ? NULL : cpl_cvsid ); }
 /** C++11 final qualifier */
 #  define CPL_FINAL final
 
+/** Mark that a class is explicitly recognized as non-final */
+#  define CPL_NON_FINAL
+
 /** Helper to remove the copy and assignment constructors so that the compiler
    will not generate the default versions.
 
@@ -1047,7 +1057,7 @@ CPL_C_END
   static_cast<size_t>(!(sizeof(array) % sizeof(*(array)))))
 
 extern "C++" {
-template<class T> static void CPL_IGNORE_RET_VAL(T) {}
+template<class T> static void CPL_IGNORE_RET_VAL(const T&) {}
 inline static bool CPL_TO_BOOL(int x) { return x != 0; }
 } /* extern "C++" */
 
@@ -1169,6 +1179,18 @@ inline bool operator!= (const bool& one, const MSVCPedanticBool& other) { return
 #else
 #define CPL_NOSANITIZE_UNSIGNED_INT_OVERFLOW
 #endif
+
+#if defined(__cplusplus) && !defined(CPL_SUPRESS_CPLUSPLUS) && defined(GDAL_COMPILATION)
+extern "C++" {
+template<class C, class A, class B>
+CPL_NOSANITIZE_UNSIGNED_INT_OVERFLOW
+inline C CPLUnsanitizedAdd(A a, B b)
+{
+    return a + b;
+}
+}
+#endif
+
 /*! @endcond */
 
 /*! @cond Doxygen_Suppress */
